..
    This file is part of Invenio.
    Copyright (C) 2020 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _main-concepts:

Main concepts
=============

.. toctree::
    :maxdepth: 2

    repository-structure
    understanding-data-models
    managing-access
    handling-files
    architecture-infrastructure
    architecture-application
    securing-your-instance
